#class_form {
    width: 150px;
}

#wrapper {
    margin-top: 30px;
    margin-left: 3%;
    margin-right: 3%;
}

table {
    width: 100%;
    border: none !important;
    border-collapse:collapse;
}

th {
    background-color: #dcdcdc;
}

tr:nth-child(odd) {
    background: #eee;
}

#class_form {
    margin-left: 20px;
    margin-bottom: 50px;
}

.student_container {
    font-size: 12pt;
    margin: 20px;
    width: 650px;
}

.student_container img {
    height: 50px;
    width: 50px;
    margin-right: 30px;
    margin-left: 30px;
}


