# Generated by Django 3.2.18 on 2023-02-28 14:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0083_add_cows_to_existing_levels'),
    ]

    operations = [
        migrations.AlterField(
            model_name='block',
            name='block_type',
            field=models.IntegerField(choices=[(0, 'Start'), (1, 'Action'), (2, 'Condition'), (3, 'Procedure'), (4, 'ControlFlow'), (5, 'Variable'), (6, 'Math')]),
        ),
    ]
